@@ -27,6 +27,9 @@ class LiveHLSException(HLSException):
 def _get_full_url(url, srcurl):
     if url[:4] == 'http':
         return url
+    if url[0] == '/':
+        baseurl = re.search(r'^(http[s]{0,1}://[^/]+)/', srcurl)
+        return "%s%s" % (baseurl.group(1), url)
 
     # remove everything after last / in the path of the URL
     baseurl = re.sub(r'^([^\?]+)/[^/]*(\?.*)?$', r'\1', srcurl)
@@ -38,13 +41,20 @@ def _get_full_url(url, srcurl):
 def hlsparse(options, res, url):
     streams = {}
 
-    if res.status_code == 403 or res.status_code == 404:
-        streams[0] = ServiceError("Can't read HLS playlist.")
+    if not res:
+        return None
+
+    if res.status_code > 400:
+        streams[0] = ServiceError("Can't read HLS playlist. {0}".format(res.status_code))
         return streams
     files = (parsem3u(res.text))[1]
 
     for i in files:
-        bitrate = float(i[1]["BANDWIDTH"])/1000
+        try:
+            bitrate = float(i[1]["BANDWIDTH"])/1000
+        except KeyError:
+            streams[0] = ServiceError("Can't read HLS playlist")
+            return streams
         streams[int(bitrate)] = HLS(copy.copy(options), _get_full_url(i[0], url), bitrate, cookies=res.cookies)
     return streams
 
