@@ -154,7 +154,9 @@ def output(options, extention="mp4", openfd=True, mode="wb", **kwargs):
             options.output = "%s.%s" % (options.output, extention)
         if options.output_auto and ext:
             options.output = "%s.%s" % (options.output, extention)
-        if extention == "srt" and ext:
+        elif extention == "srt" and ext:
+            options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
+        if ext and extention == "srt" and ext.group(1).split(".")[-1] in subtitlefiles:
             options.output = "%s.srt" % options.output[:options.output.rfind(ext.group(1))]
         log.info("Outfile: %s", options.output)
         if os.path.isfile(options.output) or \
