@@ -6,9 +6,8 @@ import json
 import copy
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
-from svtplay_dl.fetcher.rtmp import RTMP
-from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.fetcher.hls import hlsparse
+from svtplay_dl.fetcher.http import HTTP
 from svtplay_dl.error import ServiceError
 from svtplay_dl.utils.urllib import urlparse
 
@@ -17,6 +16,8 @@ class Picsearch(Service, OpenGraphThumbMixin):
     supported_domains = ['dn.se', 'mobil.dn.se', 'di.se', 'csp.picsearch.com', 'csp.screen9.com']
 
     def get(self):
+        self.backupapi = None
+
         if self.exclude():
             yield ServiceError("Excluding video")
             return
@@ -33,32 +34,30 @@ class Picsearch(Service, OpenGraphThumbMixin):
         if not isinstance(mediaid, str):
             mediaid = mediaid.group(1)
 
-        jsondata = self.http.request("get", "http://csp.picsearch.com/rest?jsonp=&eventParam=1&auth=%s&method=embed&mediaid=%s" % (ajax_auth.group(1), mediaid)).text
+        jsondata = self.http.request("get", "http://csp.screen9.com/player?eventParam=1&ajaxauth=%s&method=embed&mediaid=%s" % (ajax_auth.group(1), mediaid)).text
         jsondata = json.loads(jsondata)
-        if "playerconfig" not in jsondata["media"]:
-            yield ServiceError(jsondata["error"])
-            return
-        if "live" in jsondata["media"]["playerconfig"]["clip"]:
-            self.options.live = jsondata["media"]["playerconfig"]["clip"]
-        playlist = jsondata["media"]["playerconfig"]["playlist"][1]
-        if "bitrates" in playlist:
-            files = playlist["bitrates"]
-            server = jsondata["media"]["playerconfig"]["plugins"]["bwcheck"]["netConnectionUrl"]
 
-            for i in files:
-                self.options.other = "-y '%s'" % i["url"]
-                yield RTMP(copy.copy(self.options), server, i["height"])
-        if "provider" in playlist:
-            if playlist["provider"] != "rtmp":
-                if "live" in playlist:
-                    self.options.live = playlist["live"]
-                if playlist["url"].endswith(".f4m"):
-                    streams = hdsparse(self.options, self.http.request("get", playlist["url"], params={"hdcore": "3.7.0"}), playlist["url"])
-                    if streams:
-                        for n in list(streams.keys()):
-                            yield streams[n]
-                if ".m3u8" in playlist["url"]:
-                    streams = hlsparse(self.options, self.http.request("get", playlist["url"]), playlist["url"])
+        if "data" in jsondata:
+            if "live" in jsondata["data"]["publishing_status"]:
+                self.options.live = jsondata["data"]["publishing_status"]["live"]
+            playlist = jsondata["data"]["streams"]
+            for i in playlist:
+                    if "application/x-mpegurl" in i:
+                        streams = hlsparse(self.options, self.http.request("get", i["application/x-mpegurl"]), i["application/x-mpegurl"])
+                        if streams:
+                            for n in list(streams.keys()):
+                                yield streams[n]
+                    if "video/mp4" in i:
+                        yield HTTP(copy.copy(self.options), i["video/mp4"], 800)
+
+        if self.backupapi:
+            res = self.http.get(self.backupapi.replace("i=", ""), params={"i": "object"})
+            data = res.text.replace("ps.embedHandler(", "").replace('"");', '')
+            data = data[:data.rfind(",")]
+            jansson = json.loads(data)
+            for i in jansson["media"]["playerconfig"]["playlist"]:
+                if "provider" in i and i["provider"] == "httpstreaming":
+                    streams = hlsparse(self.options, self.http.request("get", i["url"]), i["url"])
                     if streams:
                         for n in list(streams.keys()):
                             yield streams[n]
@@ -69,17 +68,23 @@ class Picsearch(Service, OpenGraphThumbMixin):
             match = re.search(r'screen9-ajax-auth="([^"]+)"', self.get_urldata())
         if not match:
             match = re.search('screen9"[ ]*:[ ]*"([^"]+)"', self.get_urldata())
+        if not match:
+            match = re.search('data-auth="([^"]+)"', self.get_urldata())
         if not match:
             match = re.search('s.src="(https://csp-ssl.picsearch.com[^"]+|http://csp.picsearch.com/rest[^"]+)', self.get_urldata())
             if match:
                 data = self.http.request("get", match.group(1))
+                self.backupapi = match.group(1)
                 match = re.search(r'ajaxAuth": "([^"]+)"', data.text)
             if not match:
                 match = re.search('iframe src="(//csp.screen9.com[^"]+)"', self.get_urldata())
                 if match:
                     url = "http:%s" % match.group(1)
                     data = self.http.request("get", url)
+                    self.backupapi = url
                     match = re.search(r"picsearch_ajax_auth = '([^']+)'", data.text)
+                    if not match:
+                        match = re.search(r"screen9_ajax_auth = '([^']+)'", data.text)
 
         return match
 
@@ -91,6 +96,8 @@ class Picsearch(Service, OpenGraphThumbMixin):
             match = re.search(r'screen9-mid="([^"]+)"', self.get_urldata())
         if not match:
             match = re.search(r'data-id="([^"]+)"', self.get_urldata())
+        if not match:
+            match = re.search(r'data-videoid="([^"]+)"', self.get_urldata())
         if not match:
             match = re.search('s.src="(https://csp-ssl.picsearch.com[^"]+|http://csp.picsearch.com/rest[^"]+)', self.get_urldata())
             if match:
