@@ -31,13 +31,21 @@ class Solidtango(Service):
             data = self.http.request("get", match.group(1)).text
 
         match = re.search('is_livestream: true', data)
+        if match:
+            self.options.live = True
+        match = re.search('isLivestream: true', data)
         if match:
             self.options.live = True
         match = re.search('html5_source: "([^"]+)"', data)
+        match2 = re.search('hlsURI: "([^"]+)"', data)
         if match:
             streams = hlsparse(self.options, self.http.request("get", match.group(1)), match.group(1))
             for n in list(streams.keys()):
                 yield streams[n]
+        elif match2:
+            streams = hlsparse(self.options, self.http.request("get", match2.group(1)), match2.group(1))
+            for n in list(streams.keys()):
+                yield streams[n]
         else:
             parse = urlparse(self.url)
             url2 = "https://%s/api/v1/play/%s.xml" % (parse.netloc, parse.path[parse.path.rfind("/")+1:])
