@@ -120,7 +120,11 @@ class Tv4play(Service, OpenGraphThumbMixin):
 
     def _get_show_info(self):
         show = self._get_showname(self.url)
-        data = self.http.request("get", "http://webapi.tv4play.se/play/video_assets?type=episode&is_live=false&platform=web&node_nids=%s&per_page=99999" % show).text
+        if self.options.live:
+            live = "true"
+        else:
+            live = "false"
+        data = self.http.request("get", "http://webapi.tv4play.se/play/video_assets?type=episode&is_live=%s&platform=web&node_nids=%s&per_page=99999" % (live, show)).text
         jsondata = json.loads(data)
         return jsondata
 
@@ -129,8 +133,12 @@ class Tv4play(Service, OpenGraphThumbMixin):
         page = 1
         assets = page * 1000
         run = True
+        if self.options.live:
+            live = "true"
+        else:
+            live = "false"
         while run:
-            data = self.http.request("get", "http://webapi.tv4play.se/play/video_assets?type=clips&is_live=false&platform=web&node_nids=%s&per_page=1000&page=%s" % (show, page)).text
+            data = self.http.request("get", "http://webapi.tv4play.se/play/video_assets?type=clips&is_live=%s&platform=web&node_nids=%s&per_page=1000&page=%s" % (live, show, page)).text
             jsondata = json.loads(data)
             for i in jsondata["results"]:
                 if vid == i["id"]:
