@@ -142,9 +142,22 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 self.options.output = title
 
         if dataj["sami_path"]:
-            yield subtitle(copy.copy(self.options), "sami", dataj["sami_path"])
+            if dataj["sami_path"].endswith("vtt"):
+                subtype = "wrst"
+            else:
+                subtype = "sami"
+            yield subtitle(copy.copy(self.options), subtype, dataj["sami_path"])
+        if dataj["subtitles_webvtt"]:
+            yield subtitle(copy.copy(self.options), "wrst", dataj["subtitles_webvtt"])
         if dataj["subtitles_for_hearing_impaired"]:
-            yield subtitle(copy.copy(self.options), "sami", dataj["subtitles_for_hearing_impaired"])
+            if dataj["subtitles_for_hearing_impaired"].endswith("vtt"):
+                subtype = "wrst"
+            else:
+                subtype = "sami"
+            if self.options.get_all_subtitles:
+                yield subtitle(copy.copy(self.options), subtype, dataj["subtitles_for_hearing_impaired"],"-SDH")
+            else: 
+                yield subtitle(copy.copy(self.options), subtype, dataj["subtitles_for_hearing_impaired"])
 
         if streamj["streams"]["medium"]:
             filename = streamj["streams"]["medium"]
@@ -200,7 +213,7 @@ class Viaplay(Service, OpenGraphThumbMixin):
                 episode = dataj["format_position"]["episode"]
         name = filenamify(program)
         if season:
-            name = "%s.s%s" % (name, season)
+            name = "{}.s{:02d}".format(name, int(season))
         if episode:
-            name = "%se%s" % (name, episode)
+            name = "{}e{:02d}".format(name, int(episode))
         return name
\ No newline at end of file
